@@ -21,10 +21,10 @@ var searchData=
   ['envguard_18',['EnvGuard',['../a00998.html#adabaaf6b5a8445668f0725cfe86fa02a',1,'cppu::EnvGuard']]],
   ['environment_19',['Environment',['../a00982.html#a52c8a36837ad58e98784f549cd95b3ed',1,'com::sun::star::uno::Environment::Environment(uno_Environment *pEnv=NULL)'],['../a00982.html#a1224d0b31212c4465973b6652dd4c504',1,'com::sun::star::uno::Environment::Environment(rtl::OUString const &amp;envDcp, void *pContext=NULL)'],['../a00982.html#a76d19e18ab8d0d898fb552cba029e0d9',1,'com::sun::star::uno::Environment::Environment(const Environment &amp;rEnv)']]],
   ['environment_5finitwithenterable_20',['Environment_initWithEnterable',['../a00540.html#a6acec576bc79a431fd632b7a73a65f3e',1,'cppu::helper::purpenv']]],
-  ['equals_21',['equals',['../a00950.html#a9234418ef5a517af5c6e6f0b1d55f35a',1,'com::sun::star::uno::TypeDescription::equals()'],['../a00666.html#ae8c738b6b1acf0209996a759000f4529',1,'rtl::OString::equals()'],['../a00754.html#af8906c3531fdab1b1ea30ffec22bbc15',1,'rtl::OUString::equals()'],['../a00950.html#ac9a86d17cc6ae80b74f0c2a104f3e9ca',1,'com::sun::star::uno::TypeDescription::equals()'],['../a01974.html#a551931cdcaa98bceedd76d8206d80521',1,'com::sun::star::uno::Type::equals()']]],
+  ['equals_21',['equals',['../a00666.html#ae8c738b6b1acf0209996a759000f4529',1,'rtl::OString::equals()'],['../a00754.html#af8906c3531fdab1b1ea30ffec22bbc15',1,'rtl::OUString::equals()'],['../a00950.html#a9234418ef5a517af5c6e6f0b1d55f35a',1,'com::sun::star::uno::TypeDescription::equals(const typelib_TypeDescription *pTypeDescr) const'],['../a00950.html#ac9a86d17cc6ae80b74f0c2a104f3e9ca',1,'com::sun::star::uno::TypeDescription::equals(const TypeDescription &amp;rTypeDescr) const'],['../a01974.html#a551931cdcaa98bceedd76d8206d80521',1,'com::sun::star::uno::Type::equals()']]],
   ['equalsascii_22',['equalsAscii',['../a00754.html#a975abdfbab9e0c78c10307df1a5ebaa7',1,'rtl::OUString']]],
   ['equalsasciil_23',['equalsAsciiL',['../a00754.html#a5e2609800c4992774b08c8a7d2c07436',1,'rtl::OUString']]],
-  ['equalsignoreasciicase_24',['equalsIgnoreAsciiCase',['../a00666.html#adbbf466e411d68099894f0511fa49ca1',1,'rtl::OString::equalsIgnoreAsciiCase(const T &amp;asciiStr) const'],['../a00666.html#ace69f01af1e5bbd09d6fde970254f4b9',1,'rtl::OString::equalsIgnoreAsciiCase(const OString &amp;str) const'],['../a00754.html#a51cd29980d7962cc7c5fce9781ea27b3',1,'rtl::OUString::equalsIgnoreAsciiCase(T &amp;literal) const'],['../a00754.html#a19c4188312d907a6267d9ca435ff0e84',1,'rtl::OUString::equalsIgnoreAsciiCase(const OUString &amp;str) const'],['../a00666.html#a41b89297b85dc79db79bd2d91172975b',1,'rtl::OString::equalsIgnoreAsciiCase(T &amp;literal) const'],['../a00666.html#ad757daff373e4845cd7930a8af3eef98',1,'rtl::OString::equalsIgnoreAsciiCase(T &amp;asciiStr) const']]],
+  ['equalsignoreasciicase_24',['equalsIgnoreAsciiCase',['../a00666.html#ace69f01af1e5bbd09d6fde970254f4b9',1,'rtl::OString::equalsIgnoreAsciiCase(const OString &amp;str) const'],['../a00666.html#adbbf466e411d68099894f0511fa49ca1',1,'rtl::OString::equalsIgnoreAsciiCase(const T &amp;asciiStr) const'],['../a00666.html#ad757daff373e4845cd7930a8af3eef98',1,'rtl::OString::equalsIgnoreAsciiCase(T &amp;asciiStr) const'],['../a00666.html#a41b89297b85dc79db79bd2d91172975b',1,'rtl::OString::equalsIgnoreAsciiCase(T &amp;literal) const'],['../a00754.html#a19c4188312d907a6267d9ca435ff0e84',1,'rtl::OUString::equalsIgnoreAsciiCase(const OUString &amp;str) const'],['../a00754.html#a51cd29980d7962cc7c5fce9781ea27b3',1,'rtl::OUString::equalsIgnoreAsciiCase(T &amp;literal) const']]],
   ['equalsignoreasciicaseascii_25',['equalsIgnoreAsciiCaseAscii',['../a00754.html#aad245e6979066dc481bd116d413e7cf8',1,'rtl::OUString']]],
   ['equalsignoreasciicaseasciil_26',['equalsIgnoreAsciiCaseAsciiL',['../a00754.html#a2245d3d40c15586202e3f953c1a7cfbc',1,'rtl::OUString']]],
   ['equalsignoreasciicasel_27',['equalsIgnoreAsciiCaseL',['../a00666.html#afa008446aca7017ee3bfa130eeba6be1',1,'rtl::OString']]],
