@@ -240,15 +240,4 @@ var menudata={children:[
 {text:"u",url:"functions_type.html#index_u"},
 {text:"v",url:"functions_type.html#index_v"}]}]}]},
 {text:"Files",url:"files.html",children:[
-{text:"File List",url:"files.html"},
-{text:"File Members",url:"globals.html",children:[
-{text:"All",url:"globals.html",children:[
-{text:"_",url:"globals.html#index__5F"},
-{text:"c",url:"globals_c.html#index_c"},
-{text:"i",url:"globals_i.html#index_i"},
-{text:"o",url:"globals_o.html#index_o"}]},
-{text:"Macros",url:"globals_defs.html",children:[
-{text:"_",url:"globals_defs.html#index__5F"},
-{text:"c",url:"globals_defs_c.html#index_c"},
-{text:"i",url:"globals_defs_i.html#index_i"},
-{text:"o",url:"globals_defs_o.html#index_o"}]}]}]}]}
+{text:"File List",url:"files.html"}]}]}
