@@ -16,7 +16,7 @@ var searchData=
   ['calendarfieldindex_2eidl_13',['CalendarFieldIndex.idl',['../CalendarFieldIndex_8idl.html',1,'']]],
   ['calendaritem_2eidl_14',['CalendarItem.idl',['../CalendarItem_8idl.html',1,'']]],
   ['calendaritem2_2eidl_15',['CalendarItem2.idl',['../CalendarItem2_8idl.html',1,'']]],
-  ['callablestatement_2eidl_16',['callablestatement.idl',['../sdb_2CallableStatement_8idl.html',1,'(Global Namespace)'],['../sdbc_2CallableStatement_8idl.html',1,'(Global Namespace)']]],
+  ['callablestatement_2eidl_16',['CallableStatement.idl',['../sdb_2CallableStatement_8idl.html',1,'(Global Namespace)'],['../sdbc_2CallableStatement_8idl.html',1,'(Global Namespace)']]],
   ['camerageometry_2eidl_17',['CameraGeometry.idl',['../CameraGeometry_8idl.html',1,'']]],
   ['candlestickcharttype_2eidl_18',['CandleStickChartType.idl',['../CandleStickChartType_8idl.html',1,'']]],
   ['cannotactivatefactoryexception_2eidl_19',['CannotActivateFactoryException.idl',['../CannotActivateFactoryException_8idl.html',1,'']]],
@@ -35,7 +35,7 @@ var searchData=
   ['cartesiancoordinatesystem2d_2eidl_32',['CartesianCoordinateSystem2d.idl',['../CartesianCoordinateSystem2d_8idl.html',1,'']]],
   ['cartesiancoordinatesystem3d_2eidl_33',['CartesianCoordinateSystem3d.idl',['../CartesianCoordinateSystem3d_8idl.html',1,'']]],
   ['casemap_2eidl_34',['CaseMap.idl',['../CaseMap_8idl.html',1,'']]],
-  ['cell_2eidl_35',['cell.idl',['../text_2Cell_8idl.html',1,'(Global Namespace)'],['../table_2Cell_8idl.html',1,'(Global Namespace)']]],
+  ['cell_2eidl_35',['Cell.idl',['../table_2Cell_8idl.html',1,'(Global Namespace)'],['../text_2Cell_8idl.html',1,'(Global Namespace)']]],
   ['celladdress_2eidl_36',['CellAddress.idl',['../CellAddress_8idl.html',1,'']]],
   ['cellannotation_2eidl_37',['CellAnnotation.idl',['../CellAnnotation_8idl.html',1,'']]],
   ['cellannotations_2eidl_38',['CellAnnotations.idl',['../CellAnnotations_8idl.html',1,'']]],
@@ -55,9 +55,9 @@ var searchData=
   ['cellinsertmode_2eidl_52',['CellInsertMode.idl',['../CellInsertMode_8idl.html',1,'']]],
   ['celljustifymethod_2eidl_53',['CellJustifyMethod.idl',['../CellJustifyMethod_8idl.html',1,'']]],
   ['cellorientation_2eidl_54',['CellOrientation.idl',['../CellOrientation_8idl.html',1,'']]],
-  ['cellproperties_2eidl_55',['cellproperties.idl',['../text_2CellProperties_8idl.html',1,'(Global Namespace)'],['../table_2CellProperties_8idl.html',1,'(Global Namespace)']]],
+  ['cellproperties_2eidl_55',['CellProperties.idl',['../table_2CellProperties_8idl.html',1,'(Global Namespace)'],['../text_2CellProperties_8idl.html',1,'(Global Namespace)']]],
   ['cellprotection_2eidl_56',['CellProtection.idl',['../CellProtection_8idl.html',1,'']]],
-  ['cellrange_2eidl_57',['cellrange.idl',['../text_2CellRange_8idl.html',1,'(Global Namespace)'],['../table_2CellRange_8idl.html',1,'(Global Namespace)']]],
+  ['cellrange_2eidl_57',['CellRange.idl',['../table_2CellRange_8idl.html',1,'(Global Namespace)'],['../text_2CellRange_8idl.html',1,'(Global Namespace)']]],
   ['cellrangeaddress_2eidl_58',['CellRangeAddress.idl',['../CellRangeAddress_8idl.html',1,'']]],
   ['cellrangelistsource_2eidl_59',['CellRangeListSource.idl',['../CellRangeListSource_8idl.html',1,'']]],
   ['cells_2eidl_60',['Cells.idl',['../Cells_8idl.html',1,'']]],
@@ -119,7 +119,7 @@ var searchData=
   ['chartdatarowproperties_2eidl_116',['ChartDataRowProperties.idl',['../ChartDataRowProperties_8idl.html',1,'']]],
   ['chartdatarowsource_2eidl_117',['ChartDataRowSource.idl',['../ChartDataRowSource_8idl.html',1,'']]],
   ['chartdatavalue_2eidl_118',['ChartDataValue.idl',['../ChartDataValue_8idl.html',1,'']]],
-  ['chartdocument_2eidl_119',['chartdocument.idl',['../chart_2ChartDocument_8idl.html',1,'(Global Namespace)'],['../chart2_2ChartDocument_8idl.html',1,'(Global Namespace)']]],
+  ['chartdocument_2eidl_119',['ChartDocument.idl',['../chart_2ChartDocument_8idl.html',1,'(Global Namespace)'],['../chart2_2ChartDocument_8idl.html',1,'(Global Namespace)']]],
   ['chartdocumentwrapper_2eidl_120',['ChartDocumentWrapper.idl',['../ChartDocumentWrapper_8idl.html',1,'']]],
   ['charterrorcategory_2eidl_121',['ChartErrorCategory.idl',['../ChartErrorCategory_8idl.html',1,'']]],
   ['charterrorindicatortype_2eidl_122',['ChartErrorIndicatorType.idl',['../ChartErrorIndicatorType_8idl.html',1,'']]],
@@ -143,7 +143,7 @@ var searchData=
   ['charttypemanager_2eidl_140',['ChartTypeManager.idl',['../ChartTypeManager_8idl.html',1,'']]],
   ['charttypetemplate_2eidl_141',['ChartTypeTemplate.idl',['../ChartTypeTemplate_8idl.html',1,'']]],
   ['chartype_2eidl_142',['CharType.idl',['../CharType_8idl.html',1,'']]],
-  ['checkbox_2eidl_143',['checkbox.idl',['../component_2CheckBox_8idl.html',1,'(Global Namespace)'],['../control_2CheckBox_8idl.html',1,'(Global Namespace)']]],
+  ['checkbox_2eidl_143',['CheckBox.idl',['../component_2CheckBox_8idl.html',1,'(Global Namespace)'],['../control_2CheckBox_8idl.html',1,'(Global Namespace)']]],
   ['checkinargument_2eidl_144',['CheckinArgument.idl',['../CheckinArgument_8idl.html',1,'']]],
   ['checkoption_2eidl_145',['CheckOption.idl',['../CheckOption_8idl.html',1,'']]],
   ['cipherid_2eidl_146',['CipherID.idl',['../CipherID_8idl.html',1,'']]],
@@ -161,7 +161,7 @@ var searchData=
   ['cmisversion_2eidl_158',['CmisVersion.idl',['../CmisVersion_8idl.html',1,'']]],
   ['collator_2eidl_159',['Collator.idl',['../Collator_8idl.html',1,'']]],
   ['collatoroptions_2eidl_160',['CollatorOptions.idl',['../CollatorOptions_8idl.html',1,'']]],
-  ['color_2eidl_161',['color.idl',['../rendering_2Color_8idl.html',1,'(Global Namespace)'],['../util_2Color_8idl.html',1,'(Global Namespace)']]],
+  ['color_2eidl_161',['Color.idl',['../rendering_2Color_8idl.html',1,'(Global Namespace)'],['../util_2Color_8idl.html',1,'(Global Namespace)']]],
   ['colorcomponent_2eidl_162',['ColorComponent.idl',['../ColorComponent_8idl.html',1,'']]],
   ['colorcomponenttag_2eidl_163',['ColorComponentTag.idl',['../ColorComponentTag_8idl.html',1,'']]],
   ['colormode_2eidl_164',['ColorMode.idl',['../ColorMode_8idl.html',1,'']]],
@@ -170,54 +170,54 @@ var searchData=
   ['colorscale_2eidl_167',['ColorScale.idl',['../ColorScale_8idl.html',1,'']]],
   ['colorscaleentrytype_2eidl_168',['ColorScaleEntryType.idl',['../ColorScaleEntryType_8idl.html',1,'']]],
   ['colorspacetype_2eidl_169',['ColorSpaceType.idl',['../ColorSpaceType_8idl.html',1,'']]],
-  ['colortable_2eidl_170',['ColorTable.idl',['../ColorTable_8idl.html',1,'']]],
-  ['column_2eidl_171',['column.idl',['../sdbcx_2Column_8idl.html',1,'(Global Namespace)'],['../sdb_2Column_8idl.html',1,'(Global Namespace)']]],
-  ['columndescriptor_2eidl_172',['ColumnDescriptor.idl',['../ColumnDescriptor_8idl.html',1,'']]],
-  ['columndescriptorcontrol_2eidl_173',['ColumnDescriptorControl.idl',['../ColumnDescriptorControl_8idl.html',1,'']]],
-  ['columndescriptorcontrolmodel_2eidl_174',['ColumnDescriptorControlModel.idl',['../ColumnDescriptorControlModel_8idl.html',1,'']]],
-  ['columnsearch_2eidl_175',['ColumnSearch.idl',['../ColumnSearch_8idl.html',1,'']]],
-  ['columnseparatorstyle_2eidl_176',['ColumnSeparatorStyle.idl',['../ColumnSeparatorStyle_8idl.html',1,'']]],
-  ['columnsettings_2eidl_177',['ColumnSettings.idl',['../ColumnSettings_8idl.html',1,'']]],
-  ['columntype_2eidl_178',['ColumnType.idl',['../ColumnType_8idl.html',1,'']]],
-  ['columnvalue_2eidl_179',['ColumnValue.idl',['../ColumnValue_8idl.html',1,'']]],
-  ['combinedcharacters_2eidl_180',['CombinedCharacters.idl',['../CombinedCharacters_8idl.html',1,'']]],
-  ['combobox_2eidl_181',['combobox.idl',['../component_2ComboBox_8idl.html',1,'(Global Namespace)'],['../control_2ComboBox_8idl.html',1,'(Global Namespace)']]],
-  ['command_2eidl_182',['command.idl',['../awt_2Command_8idl.html',1,'(Global Namespace)'],['../animations_2Command_8idl.html',1,'(Global Namespace)'],['../ucb_2Command_8idl.html',1,'(Global Namespace)']]],
-  ['commandabortedexception_2eidl_183',['CommandAbortedException.idl',['../CommandAbortedException_8idl.html',1,'']]],
-  ['commandbutton_2eidl_184',['commandbutton.idl',['../control_2CommandButton_8idl.html',1,'(Global Namespace)'],['../component_2CommandButton_8idl.html',1,'(Global Namespace)']]],
-  ['commanddefinition_2eidl_185',['CommandDefinition.idl',['../CommandDefinition_8idl.html',1,'']]],
-  ['commandenvironment_2eidl_186',['CommandEnvironment.idl',['../CommandEnvironment_8idl.html',1,'']]],
-  ['commandfailedexception_2eidl_187',['CommandFailedException.idl',['../CommandFailedException_8idl.html',1,'']]],
-  ['commandgroup_2eidl_188',['CommandGroup.idl',['../CommandGroup_8idl.html',1,'']]],
-  ['commandinfo_2eidl_189',['CommandInfo.idl',['../CommandInfo_8idl.html',1,'']]],
-  ['commandinfochange_2eidl_190',['CommandInfoChange.idl',['../CommandInfoChange_8idl.html',1,'']]],
-  ['commandinfochangeevent_2eidl_191',['CommandInfoChangeEvent.idl',['../CommandInfoChangeEvent_8idl.html',1,'']]],
-  ['commandtype_2eidl_192',['CommandType.idl',['../CommandType_8idl.html',1,'']]],
-  ['commonfilepickerelementids_2eidl_193',['CommonFilePickerElementIds.idl',['../CommonFilePickerElementIds_8idl.html',1,'']]],
-  ['comparebookmark_2eidl_194',['CompareBookmark.idl',['../CompareBookmark_8idl.html',1,'']]],
-  ['complexreference_2eidl_195',['ComplexReference.idl',['../ComplexReference_8idl.html',1,'']]],
-  ['componentchangeevent_2eidl_196',['ComponentChangeEvent.idl',['../ComponentChangeEvent_8idl.html',1,'']]],
-  ['components_2eidl_197',['Components.idl',['../Components_8idl.html',1,'']]],
-  ['compositeoperation_2eidl_198',['CompositeOperation.idl',['../CompositeOperation_8idl.html',1,'']]],
-  ['compositiontype_2eidl_199',['CompositionType.idl',['../CompositionType_8idl.html',1,'']]],
-  ['conditionalformat_2eidl_200',['ConditionalFormat.idl',['../ConditionalFormat_8idl.html',1,'']]],
-  ['conditionaltext_2eidl_201',['ConditionalText.idl',['../ConditionalText_8idl.html',1,'']]],
-  ['conditionentrytype_2eidl_202',['ConditionEntryType.idl',['../ConditionEntryType_8idl.html',1,'']]],
-  ['conditionformatentry_2eidl_203',['ConditionFormatEntry.idl',['../ConditionFormatEntry_8idl.html',1,'']]],
-  ['conditionformatoperator_2eidl_204',['ConditionFormatOperator.idl',['../ConditionFormatOperator_8idl.html',1,'']]],
-  ['conditionoperator_2eidl_205',['ConditionOperator.idl',['../ConditionOperator_8idl.html',1,'']]],
-  ['conditionoperator2_2eidl_206',['ConditionOperator2.idl',['../ConditionOperator2_8idl.html',1,'']]],
-  ['configurableuielement_2eidl_207',['ConfigurableUIElement.idl',['../ConfigurableUIElement_8idl.html',1,'']]],
-  ['configuration_2eidl_208',['Configuration.idl',['../Configuration_8idl.html',1,'']]],
-  ['configurationaccess_2eidl_209',['ConfigurationAccess.idl',['../ConfigurationAccess_8idl.html',1,'']]],
-  ['configurationchangeevent_2eidl_210',['ConfigurationChangeEvent.idl',['../ConfigurationChangeEvent_8idl.html',1,'']]],
-  ['configurationcontroller_2eidl_211',['ConfigurationController.idl',['../ConfigurationController_8idl.html',1,'']]],
+  ['colorstop_2eidl_170',['ColorStop.idl',['../ColorStop_8idl.html',1,'']]],
+  ['colorstopsequence_2eidl_171',['ColorStopSequence.idl',['../ColorStopSequence_8idl.html',1,'']]],
+  ['colortable_2eidl_172',['ColorTable.idl',['../ColorTable_8idl.html',1,'']]],
+  ['column_2eidl_173',['Column.idl',['../sdb_2Column_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Column_8idl.html',1,'(Global Namespace)']]],
+  ['columndescriptor_2eidl_174',['ColumnDescriptor.idl',['../ColumnDescriptor_8idl.html',1,'']]],
+  ['columndescriptorcontrol_2eidl_175',['ColumnDescriptorControl.idl',['../ColumnDescriptorControl_8idl.html',1,'']]],
+  ['columndescriptorcontrolmodel_2eidl_176',['ColumnDescriptorControlModel.idl',['../ColumnDescriptorControlModel_8idl.html',1,'']]],
+  ['columnsearch_2eidl_177',['ColumnSearch.idl',['../ColumnSearch_8idl.html',1,'']]],
+  ['columnseparatorstyle_2eidl_178',['ColumnSeparatorStyle.idl',['../ColumnSeparatorStyle_8idl.html',1,'']]],
+  ['columnsettings_2eidl_179',['ColumnSettings.idl',['../ColumnSettings_8idl.html',1,'']]],
+  ['columntype_2eidl_180',['ColumnType.idl',['../ColumnType_8idl.html',1,'']]],
+  ['columnvalue_2eidl_181',['ColumnValue.idl',['../ColumnValue_8idl.html',1,'']]],
+  ['combinedcharacters_2eidl_182',['CombinedCharacters.idl',['../CombinedCharacters_8idl.html',1,'']]],
+  ['combobox_2eidl_183',['ComboBox.idl',['../component_2ComboBox_8idl.html',1,'(Global Namespace)'],['../control_2ComboBox_8idl.html',1,'(Global Namespace)']]],
+  ['command_2eidl_184',['Command.idl',['../animations_2Command_8idl.html',1,'(Global Namespace)'],['../awt_2Command_8idl.html',1,'(Global Namespace)'],['../ucb_2Command_8idl.html',1,'(Global Namespace)']]],
+  ['commandabortedexception_2eidl_185',['CommandAbortedException.idl',['../CommandAbortedException_8idl.html',1,'']]],
+  ['commandbutton_2eidl_186',['CommandButton.idl',['../component_2CommandButton_8idl.html',1,'(Global Namespace)'],['../control_2CommandButton_8idl.html',1,'(Global Namespace)']]],
+  ['commanddefinition_2eidl_187',['CommandDefinition.idl',['../CommandDefinition_8idl.html',1,'']]],
+  ['commandenvironment_2eidl_188',['CommandEnvironment.idl',['../CommandEnvironment_8idl.html',1,'']]],
+  ['commandfailedexception_2eidl_189',['CommandFailedException.idl',['../CommandFailedException_8idl.html',1,'']]],
+  ['commandgroup_2eidl_190',['CommandGroup.idl',['../CommandGroup_8idl.html',1,'']]],
+  ['commandinfo_2eidl_191',['CommandInfo.idl',['../CommandInfo_8idl.html',1,'']]],
+  ['commandinfochange_2eidl_192',['CommandInfoChange.idl',['../CommandInfoChange_8idl.html',1,'']]],
+  ['commandinfochangeevent_2eidl_193',['CommandInfoChangeEvent.idl',['../CommandInfoChangeEvent_8idl.html',1,'']]],
+  ['commandtype_2eidl_194',['CommandType.idl',['../CommandType_8idl.html',1,'']]],
+  ['commonfilepickerelementids_2eidl_195',['CommonFilePickerElementIds.idl',['../CommonFilePickerElementIds_8idl.html',1,'']]],
+  ['comparebookmark_2eidl_196',['CompareBookmark.idl',['../CompareBookmark_8idl.html',1,'']]],
+  ['complexreference_2eidl_197',['ComplexReference.idl',['../ComplexReference_8idl.html',1,'']]],
+  ['componentchangeevent_2eidl_198',['ComponentChangeEvent.idl',['../ComponentChangeEvent_8idl.html',1,'']]],
+  ['components_2eidl_199',['Components.idl',['../Components_8idl.html',1,'']]],
+  ['compositeoperation_2eidl_200',['CompositeOperation.idl',['../CompositeOperation_8idl.html',1,'']]],
+  ['compositiontype_2eidl_201',['CompositionType.idl',['../CompositionType_8idl.html',1,'']]],
+  ['conditionalformat_2eidl_202',['ConditionalFormat.idl',['../ConditionalFormat_8idl.html',1,'']]],
+  ['conditionaltext_2eidl_203',['ConditionalText.idl',['../ConditionalText_8idl.html',1,'']]],
+  ['conditionentrytype_2eidl_204',['ConditionEntryType.idl',['../ConditionEntryType_8idl.html',1,'']]],
+  ['conditionformatentry_2eidl_205',['ConditionFormatEntry.idl',['../ConditionFormatEntry_8idl.html',1,'']]],
+  ['conditionformatoperator_2eidl_206',['ConditionFormatOperator.idl',['../ConditionFormatOperator_8idl.html',1,'']]],
+  ['conditionoperator_2eidl_207',['ConditionOperator.idl',['../ConditionOperator_8idl.html',1,'']]],
+  ['conditionoperator2_2eidl_208',['ConditionOperator2.idl',['../ConditionOperator2_8idl.html',1,'']]],
+  ['configurableuielement_2eidl_209',['ConfigurableUIElement.idl',['../ConfigurableUIElement_8idl.html',1,'']]],
+  ['configurationaccess_2eidl_210',['ConfigurationAccess.idl',['../ConfigurationAccess_8idl.html',1,'']]],
+  ['configurationchangeevent_2eidl_211',['ConfigurationChangeEvent.idl',['../ConfigurationChangeEvent_8idl.html',1,'']]],
   ['configurationevent_2eidl_212',['ConfigurationEvent.idl',['../ConfigurationEvent_8idl.html',1,'']]],
   ['configurationprovider_2eidl_213',['ConfigurationProvider.idl',['../ConfigurationProvider_8idl.html',1,'']]],
   ['configurationregistry_2eidl_214',['ConfigurationRegistry.idl',['../ConfigurationRegistry_8idl.html',1,'']]],
   ['configurationupdateaccess_2eidl_215',['ConfigurationUpdateAccess.idl',['../ConfigurationUpdateAccess_8idl.html',1,'']]],
   ['connectexception_2eidl_216',['ConnectException.idl',['../ConnectException_8idl.html',1,'']]],
-  ['connection_2eidl_217',['connection.idl',['../sdbc_2Connection_8idl.html',1,'(Global Namespace)'],['../sdb_2Connection_8idl.html',1,'(Global Namespace)']]],
+  ['connection_2eidl_217',['Connection.idl',['../sdb_2Connection_8idl.html',1,'(Global Namespace)'],['../sdbc_2Connection_8idl.html',1,'(Global Namespace)']]],
   ['connectionlostexception_2eidl_218',['ConnectionLostException.idl',['../ConnectionLostException_8idl.html',1,'']]],
   ['connectionmode_2eidl_219',['ConnectionMode.idl',['../ConnectionMode_8idl.html',1,'']]],
   ['connectionpool_2eidl_220',['ConnectionPool.idl',['../ConnectionPool_8idl.html',1,'']]],
@@ -293,9 +293,9 @@ var searchData=
   ['cryptographyexception_2eidl_290',['CryptographyException.idl',['../CryptographyException_8idl.html',1,'']]],
   ['csvlogformatter_2eidl_291',['CsvLogFormatter.idl',['../CsvLogFormatter_8idl.html',1,'']]],
   ['ctlscripttype_2eidl_292',['CTLScriptType.idl',['../CTLScriptType_8idl.html',1,'']]],
-  ['currency_2eidl_293',['currency.idl',['../offapi_2com_2sun_2star_2i18n_2Currency_8idl.html',1,'(Global Namespace)'],['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Currency_8idl.html',1,'(Global Namespace)']]],
+  ['currency_2eidl_293',['Currency.idl',['../offapi_2com_2sun_2star_2i18n_2Currency_8idl.html',1,'(Global Namespace)'],['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Currency_8idl.html',1,'(Global Namespace)']]],
   ['currency2_2eidl_294',['Currency2.idl',['../Currency2_8idl.html',1,'']]],
-  ['currencyfield_2eidl_295',['currencyfield.idl',['../control_2CurrencyField_8idl.html',1,'(Global Namespace)'],['../component_2CurrencyField_8idl.html',1,'(Global Namespace)']]],
+  ['currencyfield_2eidl_295',['CurrencyField.idl',['../component_2CurrencyField_8idl.html',1,'(Global Namespace)'],['../control_2CurrencyField_8idl.html',1,'(Global Namespace)']]],
   ['curvestyle_2eidl_296',['CurveStyle.idl',['../CurveStyle_8idl.html',1,'']]],
   ['custom_2eidl_297',['Custom.idl',['../Custom_8idl.html',1,'']]],
   ['custompresentation_2eidl_298',['CustomPresentation.idl',['../CustomPresentation_8idl.html',1,'']]],
