@@ -64,7 +64,7 @@ var searchData=
   ['eventexception_2eidl_61',['EventException.idl',['../EventException_8idl.html',1,'']]],
   ['eventhandler_2eidl_62',['EventHandler.idl',['../EventHandler_8idl.html',1,'']]],
   ['eventlistener_2eidl_63',['EventListener.idl',['../EventListener_8idl.html',1,'']]],
-  ['eventobject_2eidl_64',['eventobject.idl',['../offapi_2com_2sun_2star_2document_2EventObject_8idl.html',1,'(Global Namespace)'],['../udkapi_2com_2sun_2star_2lang_2EventObject_8idl.html',1,'(Global Namespace)']]],
+  ['eventobject_2eidl_64',['EventObject.idl',['../offapi_2com_2sun_2star_2document_2EventObject_8idl.html',1,'(Global Namespace)'],['../udkapi_2com_2sun_2star_2lang_2EventObject_8idl.html',1,'(Global Namespace)']]],
   ['events_2eidl_65',['Events.idl',['../Events_8idl.html',1,'']]],
   ['eventtrigger_2eidl_66',['EventTrigger.idl',['../EventTrigger_8idl.html',1,'']]],
   ['eventtype_2eidl_67',['EventType.idl',['../EventType_8idl.html',1,'']]],
@@ -76,7 +76,7 @@ var searchData=
   ['expandvetoexception_2eidl_73',['ExpandVetoException.idl',['../ExpandVetoException_8idl.html',1,'']]],
   ['exponentialregressioncurve_2eidl_74',['ExponentialRegressionCurve.idl',['../ExponentialRegressionCurve_8idl.html',1,'']]],
   ['exponentialscaling_2eidl_75',['ExponentialScaling.idl',['../ExponentialScaling_8idl.html',1,'']]],
-  ['exportfilter_2eidl_76',['exportfilter.idl',['../document_2ExportFilter_8idl.html',1,'(Global Namespace)'],['../xml_2ExportFilter_8idl.html',1,'(Global Namespace)']]],
+  ['exportfilter_2eidl_76',['ExportFilter.idl',['../document_2ExportFilter_8idl.html',1,'(Global Namespace)'],['../xml_2ExportFilter_8idl.html',1,'(Global Namespace)']]],
   ['exportstreaminfo_2eidl_77',['ExportStreamInfo.idl',['../ExportStreamInfo_8idl.html',1,'']]],
   ['extaltnametype_2eidl_78',['ExtAltNameType.idl',['../ExtAltNameType_8idl.html',1,'']]],
   ['extendedfilepickerelementids_2eidl_79',['ExtendedFilePickerElementIds.idl',['../ExtendedFilePickerElementIds_8idl.html',1,'']]],
